@@ -36,7 +36,11 @@ use Lintian::Check qw(check_maintainer);
 use Lintian::Relation qw(:constants);
 use Lintian::Relation::Version qw(versions_compare);
 use Lintian::Tags qw(tag);
-use Lintian::Util qw($PKGNAME_REGEX);
+use Lintian::Util qw($PKGNAME_REGEX $PKGVERSION_REGEX);
+
+use constant {
+    BUILT_USING_REGEX => qr/^$PKGNAME_REGEX \(= $PKGVERSION_REGEX\)$/o,
+};
 
 our $KNOWN_ESSENTIAL = Lintian::Data->new('fields/essential');
 our $KNOWN_METAPACKAGES = Lintian::Data->new('fields/metapackages');
@@ -99,7 +103,7 @@ my @NAME_SECTION_MAPPINGS = (
     [qr/-dbg(?:sym)?$/                => 'debug'],
     [qr/^(?:python-)?zope/            => 'zope'],
     [qr/^python-/                     => 'python'],
-    [qr/^r-(?:cran|bioc)-/            => 'gnu-r'],
+    [qr/^r-(?:cran|bioc|other)-/      => 'gnu-r'],
     [qr/^lib.*-perl$/                 => 'perl'],
     [qr/^lib.*-cil(?:-dev)?$/         => 'cli-mono'],
     [qr/^lib.*-(?:java|gcj)$/         => 'java'],
@@ -619,6 +623,9 @@ sub run {
         if ($homepage=~ m,/cran\.r-project\.org/web/packages/.+,){
             tag 'homepage-for-cran-package-not-canonical', $orig;
         }
+        if ($homepage=~ m,bioconductor\.org/packages/.*/bioc/html/.*\.html*$,){
+            tag 'homepage-for-bioconductor-package-not-canonical', $orig;
+        }
     } elsif (not $info->native) {
         if ($type eq 'source') {
             my $binary_has_homepage_field = 0;
@@ -932,6 +939,22 @@ sub run {
         }
     }
 
+    #---- Built-Using
+    if (defined(my $built_using = $info->field('built-using'))) {
+        my $built_using_rel = Lintian::Relation->new($built_using);
+        $built_using_rel->visit(
+            sub {
+                if ($_ !~ BUILT_USING_REGEX) {
+                    tag 'invalid-value-in-built-using-field', $_;
+                    return 1;
+                }
+                return 0;
+            },
+            VISIT_OR_CLAUSE_FULL | VISIT_STOP_FIRST_MATCH
+        );
+
+    }
+
     #---- Package relations (source package)
 
     if ($type eq 'source') {
